

------ SIR BASIC -- version 1 
function createObserverChart (terrame_object, plotLabels)
	chart = Observer {
		subject     = terrame_object,
		attributes  = plotLabels.attributes,
		curveLabels = plotLabels.attributes,
		title       = plotLabels.title,
		xLabel      = plotLabels.xLabel,
		yLabel      = plotLabels.yLabel,
		type = "chart"
	}
end

----
function createPlot (model)

	model.plot = Cell (model.variables)
	createObserverChart (model.plot, model.plotLabels)
	model.plot:notify(0) 

end
------------------
function createTimer (model)

	model.timer = Timer {
		Event{time = 1, period = 1, action = function(e)
			changes(model)    -- 
			model.plot:notify(e:getTime()) 
		end}
	}
end


-------------------

function changes (model)

	model.auxiliary.precipitation = model.auxiliary.surfaceArea * model.constants.precipitationRate

	model.auxiliary.evaporation   = model.auxiliary.surfaceArea * model.constants.evaporationRate

	model.variables.waterInTheLake = model.variables.waterInTheLake 
		+ model.auxiliary.precipitation
		+ model.constants.runoff    -- water from the mountains
		+ model.constants.otherIn
		- model.auxiliary.evaporation
		- model.auxiliary.export
		- model.constants.otherOut

	if (model.variables.waterInTheLake <= 0 ) then
		model.variables.waterInTheLake = 0
	end

end

-----------------

function run (model, time)
	model.timer:execute (time)
end

-----------
function SystemDynamicsModel(model)

	-- create Plot
	createPlot (model)

	-- timer
	createTimer (model)

	return model
end
---------
model =  SystemDynamicsModel {
	plotLabels = {
		attributes = {"waterInTheLake"},
		title      = {"MonoLake"},
		xLabel     = {"years"},
		yLabel     = {"KAF (kilo acre-feet)"}
	},
	variables     = { waterInTheLake = 2228},
	auxiliary     = { evaporation = 0, precipitation = 0, export = 100, surfaceArea = 39},
	constants     = { runoff = 150, precipitationRate = 0.667, evaporationRate = 3.75, 
					  otherIn = 47.6, otherOut = 33.6}
}


-----
run (model, 40) 




